Installation — ACID_code documentation

# Installation

## Installing the package

ACID is currently compatable with python=3.7 due to issues arising from the multiprocessing module in newer versions of python (hopefully to be remedied in upcoming releases!). It is therefore recommended to create a conda environment to avoid downgrading your local python installation.

In this example we create an environment named ‘acid’ and activate it using:

    conda create -n acid python=3.7
    conda acivate acid

Once the environment has been activated ACID can be installed using pip:

    pip install ACID_code

## Installing from the source

In order to use the example data (for the tutorials) or the test suite ACID will need to be installed from the source (i.e. directly from the GitHub repository). This can be done by cloning the source repository and installing from there.

    git clone https://github.com/ldolan05/ACID.git
    cd ACID
    python -m pip install -e .

## Testing the installation

Test your installation by running our test file in the root repository. This mau take a while but should run without any errors if the installation has gone smoothly.

    python tests/easy_test.py